==> mirascope-1.0.2.tar.gz: mirascope-1.0.2/docs/cookbook/index.md <==
# Cookbook

This section is designed to provide you with practical, hands-on examples of how to leverage Mirascope's powerful features to solve real-world problems. Whether you're new to Mirascope or an experienced user looking for advanced techniques, our cookbook recipes offer step-by-step guides to help you build sophisticated AI-powered applications.

## What You'll Find Here

Each recipe in our cookbook:

- Focuses on a specific use case or problem
- Provides a complete, working solution using Mirascope
- Explains key concepts and techniques used
- Offers tips for adapting the solution to your specific needs

## Quick Links

Here are some popular recipes to get you started:

- [Web Search Agent](./agents/web_search_agent.md): Build an agent that can search the web and answer questions
- [SQL Agent](./agents/generating_sql_agent.md): Use LLMs to generate SQL and operate as a data analysis co-pilot
- [Text Classification](./text_classification.md): Learn how to classify text into labels
- [Text Summarization](./text_summarization.md): Learn how to create concise summaries of long texts
- [Support Ticket Routing](./support_ticket_routing.md): Automate customer support ticket classification and routing
- [Query Plan Generation](./query_plan.md): Generate efficient query plans for complex questions

## How to Use This Cookbook

1. Browse the recipes or use the search function to find a solution that matches your needs
2. Follow the step-by-step instructions in each recipe
3. Experiment with the code and adapt it to your specific use case
4. Check the "Additional Real-World Applications" section in each recipe for more ideas

## Contributing

We're always looking to expand our cookbook with new recipes. If you have a great use case or solution using Mirascope, consider contributing to our cookbook! Check out our [contribution guidelines](../CONTRIBUTING.md) for more information.

==> mirascope-1.2.1.tar.gz: mirascope-1.2.1/docs/cookbook/index.md <==
# Cookbook

This section is designed to provide you with practical, hands-on examples of how to leverage Mirascope's powerful features to solve real-world problems. Whether you're new to Mirascope or an experienced user looking for advanced techniques, our cookbook recipes offer step-by-step guides to help you build sophisticated AI-powered applications.

## What You'll Find Here

Each recipe in our cookbook:

- Focuses on a specific use case or problem
- Provides a complete, working solution using Mirascope
- Explains key concepts and techniques used
- Offers tips for adapting the solution to your specific needs

## Quick Links

Here are some popular recipes to get you started:

- [Web Search Agent](./agents/web_search_agent.md): Build an agent that can search the web and answer questions
- [SQL Agent](./agents/sql_agent.md): Use LLMs to generate SQL and operate as a data analysis co-pilot
- [Text Classification](./text_classification.md): Learn how to classify text into labels
- [Text Summarization](./text_summarization.md): Learn how to create concise summaries of long texts
- [Support Ticket Routing](./support_ticket_routing.md): Automate customer support ticket classification and routing
- [Query Plan Generation](./query_plan.md): Generate efficient query plans for complex questions

## How to Use This Cookbook

1. Browse the recipes or use the search function to find a solution that matches your needs
2. Follow the step-by-step instructions in each recipe
3. Experiment with the code and adapt it to your specific use case
4. Check the "Additional Real-World Applications" section in each recipe for more ideas

## Contributing

We're always looking to expand our cookbook with new recipes. If you have a great use case or solution using Mirascope, consider contributing to our cookbook! Check out our [contribution guidelines](../CONTRIBUTING.md) for more information.
